from NanoLanguage import *
# -------------------------------------------------------------
# Bulk configuration
# -------------------------------------------------------------

# Set up lattice
lattice = FaceCenteredCubic(5.4306*Angstrom)

# Define elements
elements = [Silicon, Silicon]

# Define coordinates
fractional_coordinates = [[ 0.  ,  0.  ,  0.  ],
                          [ 0.25,  0.25,  0.25]]

# Set up configuration
bulk_configuration = BulkConfiguration(
    bravais_lattice=lattice,
    elements=elements,
    fractional_coordinates=fractional_coordinates
    )

# -------------------------------------------------------------
# Calculator
# -------------------------------------------------------------
#----------------------------------------
# Basis Set
#----------------------------------------
basis_set = [
    LDABasis.Silicon_SingleZetaPolarized,
    ]

for tb09 in (0.9,1.0,1.1,1.2):
    #----------------------------------------
    # Exchange-Correlation
    #----------------------------------------
    exchange_correlation = MGGA.TB09LDA(c=tb09)

    numerical_accuracy_parameters = NumericalAccuracyParameters(
        k_point_sampling=(25, 25, 25),
        )

    calculator = LCAOCalculator(
        basis_set=basis_set,
        exchange_correlation=exchange_correlation,
        numerical_accuracy_parameters=numerical_accuracy_parameters,
        )

    bulk_configuration.setCalculator(calculator)
    nlprint(bulk_configuration)
    bulk_configuration.update()
    nlsave('MGGA_bulk.nc', bulk_configuration)
    # -------------------------------------------------------------
    # Bandstructure
    # -------------------------------------------------------------
    bandstructure = Bandstructure(
        configuration=bulk_configuration,
        route=['L', 'G', 'X', 'U', 'K', 'G'],
        points_per_segment=401,
        bands_above_fermi_level=All
        )
    nlsave('MGGA_bulk.nc', bandstructure)

